/////////////////////////////////////////////////////////////////////////////
///
/// @file Facade.h
///
/// This module implements interface for VM authentication.
///
/// @author shrike
///
/// Copyright (c) 2005-2017, Parallels International GmbH
/// Copyright (c) 2017-2020 Virtuozzo International GmbH, All rights reserved.
///
/// This file is part of Virtuozzo Core. Virtuozzo Core is free
/// software; you can redistribute it and/or modify it under the terms
/// of the GNU General Public License as published by the Free Software
/// Foundation; either version 2 of the License, or (at your option) any
/// later version.
///
/// This program is distributed in the hope that it will be useful,
/// but WITHOUT ANY WARRANTY; without even the implied warranty of
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/// GNU General Public License for more details.
///
/// You should have received a copy of the GNU General Public License
/// along with this program; if not, write to the Free Software
/// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
/// 02110-1301, USA.
///
/// Our contact details: Virtuozzo International GmbH, Vordergasse 59, 8200
/// Schaffhausen, Switzerland.
///
///////////////////////////////////////////////////////////////////////////////

#ifndef	__FACADE__H__
#define	__FACADE__H__

#include <boost/variant.hpp>
#include <guestfs.h>

#include "Linux.h"
#include "Windows.h"

struct Facade
{
	typedef boost::variant<Linux, Windows::Engine> os_type;

	explicit Facade(guestfs_h* handle_): m_handle(handle_)
	{
	}

	Prl::Expected<void, int> mount(const std::string& root_) const;
	Prl::Expected<std::string, int> getOsRoot() const;
	Prl::Expected<os_type, int> getOsType(const std::string& root_) const;
	Prl::Expected<FILE*, int> download(const char* path_) const;

private:
	static void free(char** list_);

	guestfs_h* m_handle;
};

#endif // __FACADE__H__
