/////////////////////////////////////////////////////////////////////////////
///
/// @file IBasicFunctions.h
///
/// @author nobody
///
/// Copyright (c) 2005-2017, Parallels International GmbH
/// Copyright (c) 2017-2019 Virtuozzo International GmbH, All rights reserved.
///
/// This file is part of Virtuozzo Core. Virtuozzo Core is free
/// software; you can redistribute it and/or modify it under the terms
/// of the GNU General Public License as published by the Free Software
/// Foundation; either version 2 of the License, or (at your option) any
/// later version.
///
/// This program is distributed in the hope that it will be useful,
/// but WITHOUT ANY WARRANTY; without even the implied warranty of
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/// GNU General Public License for more details.
///
/// You should have received a copy of the GNU General Public License
/// along with this program; if not, write to the Free Software
/// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
/// 02110-1301, USA.
///
/// Our contact details: Virtuozzo International GmbH, Vordergasse 59, 8200
/// Schaffhausen, Switzerland.
///
///////////////////////////////////////////////////////////////////////////////

#ifndef	__BASIC__INTERFACE__
#define	__BASIC__INTERFACE__

#include <QString>
#include "WinRegistryErrors.h"

///////////////////////////////////////////////////////////////////////////////
// class IBasicFunctions

class IBasicFunctions
{
protected:
	virtual ~IBasicFunctions() {};
public:
	virtual err_status_t OpenKey(const QString& sKeyName,
								 quint32& dwKeyOffset,
								 quint32 dwParentOffset = (quint32) -1) = 0;
	virtual err_status_t CreateKey(const QString& sKeyName,
								   quint32& dwKeyOffset,
								   quint32 dwOffset = (quint32) -1) = 0;
	virtual err_status_t DeleteKey(const QString& sKeyName,
								   quint32 dwOffset = (quint32) -1) = 0;
	virtual err_status_t QueryInfoKey(quint32 dwOffset,
									  QString* psClassName,
									  quint32* pcSubKeys,
									  quint16* pMaxSubKeyLen,
									  quint16* pMaxClassLen,
									  quint32* pcValues,
									  quint16* pMaxValueLen,
									  quint32* pMaxValueDataLen) = 0;
	virtual err_status_t EnumKey(quint32 dwOffset,
								 quint32 dwIndex,
								 QString* psName,
								 QString* psClass) = 0;
	virtual err_status_t CreateValue(quint32 dwNKoffset,
									 const QString& sValueName,
									 quint32 dwValueType) = 0;
	virtual err_status_t DeleteValue(quint32 dwNKoffset,
									 const QString& sValueName) = 0;

	// FIXME:
	// pdwValueType is half hack solution! If you may do not use pdwValueType
	// do it. This parameter was added by mityak@ only for implementation
	// CRegistry::RenameValue.
	virtual err_status_t GetValueData(
								quint32			dwNKoffset,
								const QString&	sValueName,
								quint32			dwValueType,
								quint8*			pBuf,
								quint32			dwBufSize,
								quint32&		dwRealDataSize,
								quint32*		pdwValueType = NULL) = 0;

	virtual err_status_t SetValueData(quint32 dwNKoffset,
									  const QString& sValueName,
									  quint32 dwValueType,
									  quint8* pBuf,
									  quint32 dwBufSize) = 0;
	virtual err_status_t EnumValue(quint32 dwOffset,
								   quint32 dwIndex,
								   QString* psValue,
								   quint32* pdwType,
								   quint8* pData,
								   quint32* pdwDataSize) = 0;
	virtual void Free() = 0;
};

#endif // __BASIC__INTERFACE__
