/////////////////////////////////////////////////////////////////////////////
///
/// @file WinRegistryErrors.h
///
/// @author ArtemK@
///
/// Copyright (c) 2005-2017, Parallels International GmbH
/// Copyright (c) 2017-2019 Virtuozzo International GmbH, All rights reserved.
///
/// This file is part of Virtuozzo Core. Virtuozzo Core is free
/// software; you can redistribute it and/or modify it under the terms
/// of the GNU General Public License as published by the Free Software
/// Foundation; either version 2 of the License, or (at your option) any
/// later version.
///
/// This program is distributed in the hope that it will be useful,
/// but WITHOUT ANY WARRANTY; without even the implied warranty of
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/// GNU General Public License for more details.
///
/// You should have received a copy of the GNU General Public License
/// along with this program; if not, write to the Free Software
/// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
/// 02110-1301, USA.
///
/// Our contact details: Virtuozzo International GmbH, Vordergasse 59, 8200
/// Schaffhausen, Switzerland.
///
///////////////////////////////////////////////////////////////////////////////

#ifndef VI_COMMON_WINREGISTRYERRORS_H
#define VI_COMMON_WINREGISTRYERRORS_H

#include <prlsdk/PrlErrors.h>

typedef PRL_RESULT err_status_t;

namespace WinRegistry
{

enum
{
	REG_IO_ERROR			= PRL_ERR_FILE_READ_ERROR, //<!
	REG_EMPTY_STORAGE_ERROR		= PRL_ERR_NO_DATA, //<!
	REG_EMPTY_EXECUTOR_ERROR	= PRL_ERR_INVALID_HANDLE, //<!
	REG_ZERO_CELL_SIZE_ERROR	= PRL_ERR_PARSE_FILESYSTEM_INFO, //<!
	REG_NO_FREE_CELL_ERROR		= PRL_ERR_NO_DATA, //<!
	REG_ALLOCATE_SPACE_ERROR	= PRL_ERR_MEMORY_ALLOC_ERROR, //<!
	REG_FREE_CELL_ERROR		= PRL_ERR_FAILURE, //<!
	REG_INCORECT_BIN_ERROR		= PRL_ERR_INVALID_HANDLE, //<!
	REG_INCORRECT_NK_CELL_ERROR	= PRL_ERR_INVALID_HANDLE, //<!
	REG_INCORRECT_INDEX_CELL_ERROR	= PRL_ERR_INVALID_HANDLE, //<!
	REG_INCORRECT_VK_CELL_ERROR	= PRL_ERR_INVALID_HANDLE, //<!
	REG_INDEXES_ARRAY_FULL_ERROR	= PRL_ERR_BUFFER_OVERRUN, //<!
	REG_KEY_NOT_FOUND_ERROR		= PRL_ERR_FILE_NOT_FOUND, //<!
	REG_KEY_ALREADY_EXISTS_ERROR	= PRL_ERR_ENTRY_ALREADY_EXISTS, //<!
	REG_KEY_NAME_EMPTY_ERROR	= PRL_ERR_VM_NAME_IS_EMPTY, //<!
	REG_KEY_NO_SUBKEY_ERROR		= PRL_ERR_ENTRY_DOES_NOT_EXIST, //<!
	REG_KEY_NOT_EMPTY_ERROR		= PRL_ERR_INVALID_HANDLE, //<!
	REG_KEY_NO_VALUE_ERROR		= PRL_ERR_NO_DATA, //<!
	REG_VALUE_ALREADY_EXIST_ERROR	= PRL_ERR_ENTRY_ALREADY_EXISTS, //<!
	REG_VALUE_NOT_EXIST_ERROR	= PRL_ERR_ENTRY_DOES_NOT_EXIST, //<!
	REG_VALUE_IS_EMPTY_ERROR	= PRL_ERR_NO_DATA, //<!
	REG_BUFFER_TOO_SMALL_ERROR	= PRL_ERR_INVALID_MEMORY_SIZE, //<!
	REG_INDEX_TOO_LARGE		= PRL_ERR_INVALID_ARG, //<!
	REG_INCORRECT_DATA_TYPE_ERROR	= PRL_ERR_INVALID_ARG, //<!
	REG_REALLOCATE_ERROR		= PRL_ERR_FAILURE, //<!
	REG_UNSUPPORTED_ERROR		= PRL_ERR_UNIMPLEMENTED, //<!
	REG_UNKNOWN_ERROR		= PRL_ERR_UNEXPECTED //<!
};

} // namespace WinRegistry

#endif //VI_COMMON_WINREGISTRYERRORS_H
