/////////////////////////////////////////////////////////////////////////////
///
/// @file wincrypt.h
///
/// @author igor
///
/// Copyright (c) 2005-2017, Parallels International GmbH
/// Copyright (c) 2017-2019 Virtuozzo International GmbH, All rights reserved.
///
/// This file is part of Virtuozzo Core. Virtuozzo Core is free
/// software; you can redistribute it and/or modify it under the terms
/// of the GNU General Public License as published by the Free Software
/// Foundation; either version 2 of the License, or (at your option) any
/// later version.
///
/// This program is distributed in the hope that it will be useful,
/// but WITHOUT ANY WARRANTY; without even the implied warranty of
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/// GNU General Public License for more details.
///
/// You should have received a copy of the GNU General Public License
/// along with this program; if not, write to the Free Software
/// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
/// 02110-1301, USA.
///
/// Our contact details: Virtuozzo International GmbH, Vordergasse 59, 8200
/// Schaffhausen, Switzerland.
///
///////////////////////////////////////////////////////////////////////////////

#ifndef __WINCRYPT_H__
#define __WINCRYPT_H__

///////////////////////////////////////////////////////////////////////////////
// struct _PSWD_CRYPTED_DATA

typedef struct _PSWD_CRYPTED_DATA
{
	uint32_t	Revision;
	// Note that the data field is missed for empty password
	uint8_t	Hash[0x10];
} PSWD_CRYPTED_DATA, *PPSWD_CRYPTED_DATA;

///////////////////////////////////////////////////////////////////////////////
// struct _USER_V

typedef struct _USER_V
{

	int u1_1;
	int u1_2;
	int u1_3;

	int username_shift;
	int username_size;

	int u2_1;

	int fullname_shift;
	int fullname_size;

	int u3_1;

	int comment_shift;
	int comment_size;

	int u4_1;
	int u4_2;
	int u4_3;
	int u4_4;
	int u4_5;
	int u4_6;
	int u4_7;

	int homedir_shift;
	int homedir_size;

	int u5_1;

	int drvletter_shift;
	int drvletter_size;

	int u6_1;

	int logonscr_shift;
	int logonscr_size;

	int u7_1;

	int profilep_shift;
	int profilep_size;

	char u7[0x1C];

	int u8_1;
	int u8_2;
	int u8_3;

	int lmpw_shift;
	int lmpw_size;

	int u9_1;

	int ntpw_shift;
	int ntpw_size;

	int u_1;
	int u_2;
	int u_3;
	int u_4;
	int u_5;
	int u_6;
	int u_7;

	uint8_t data[1];
} USER_V, *PUSER_V;

#define SAM_KEY_DATA_SALT_LENGTH        16
#define SAM_KEY_DATA_KEY_LENGTH		16
#define LM_NTLM_HASH_LENGTH		16
#define MD5_DIGEST_LENGTH		16

///////////////////////////////////////////////////////////////////////////////
// struct _SAM_KEY_DATA

typedef struct _SAM_KEY_DATA
{
	uint32_t revision;
	uint32_t length;
	uint8_t salt[SAM_KEY_DATA_SALT_LENGTH];
	uint8_t key[SAM_KEY_DATA_KEY_LENGTH];
	uint8_t checksum[MD5_DIGEST_LENGTH];
	uint32_t u_0;
	uint32_t u_1;
} SAM_KEY_DATA, *PSAM_KEY_DATA;

///////////////////////////////////////////////////////////////////////////////
// struct _SAM_HASH

typedef struct _SAM_HASH
{
	uint16_t pekid;     
	uint16_t revision;  
	uint8_t hash[LM_NTLM_HASH_LENGTH];
} SAM_HASH, *PSAM_HASH;

///////////////////////////////////////////////////////////////////////////////
// struct _SAM_HASH_AES

typedef struct _SAM_HASH_AES
{
	uint16_t pekid;
	uint16_t revision;          
	uint32_t dataoffset;
	uint8_t salt[SAM_KEY_DATA_SALT_LENGTH];
	uint8_t data[1];
} SAM_HASH_AES, *PSAM_HASH_AES;

///////////////////////////////////////////////////////////////////////////////
// struct _SAM_KEY_DATA_AES

typedef struct _SAM_KEY_DATA_AES {
	uint32_t revision;
	uint32_t length;
	uint32_t checklen;
	uint32_t datalen;
	uint8_t salt[SAM_KEY_DATA_SALT_LENGTH];
	uint8_t data[1];
} SAM_KEY_DATA_AES, *PSAM_KEY_DATA_AES;

#endif // __WINCRYPT_H__

